"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _styledBase = _interopRequireDefault(require("@emotion/styled-base"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _icons = _interopRequireDefault(require("./Icon/icons"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const IconWrapper = (0, _styledBase.default)("span", {
  target: "ei6fm2r0",
  label: "IconWrapper"
})("display:inline-block;line-height:0;width:", props => props.size, ";height:", props => props.size, ";transform:", props => `rotate(${props.rotation})`, ";& path:not(.no-fill),& circle:not(.no-fill),& polygon:not(.no-fill),& rect:not(.no-fill){fill:currentColor;}& path.clipped{fill:transparent;}svg{width:100%;height:100%;}");
/**
 * Calculates rotation for icons that have a `direction` property configured
 * in the imported icon definition object. If no direction is configured, a
 * neutral rotation value is returned.
 *
 * Returned value is a string of shape `${degrees}deg`, for use in a CSS
 * transform.
 */

const getRotation = (iconDirection, newDirection) => {
  if (!iconDirection || !newDirection) {
    return '0deg';
  }

  const rotations = {
    right: 90,
    down: 180,
    left: 270,
    up: 360
  };
  const degrees = rotations[newDirection] - rotations[iconDirection];
  return `${degrees}deg`;
};

const sizes = {
  xsmall: '12px',
  small: '18px',
  medium: '24px',
  large: '32px'
};

const Icon = (_ref) => {
  let type = _ref.type,
      direction = _ref.direction,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      className = _ref.className;
  return _react.default.createElement(IconWrapper, {
    className: className,
    dangerouslySetInnerHTML: {
      __html: _icons.default[type].image
    },
    size: sizes[size] || size,
    rotation: getRotation(_icons.default[type].direction, direction)
  });
};

Icon.propTypes = {
  type: _propTypes.default.string.isRequired,
  direction: _propTypes.default.oneOf(['right', 'down', 'left', 'up']),
  size: _propTypes.default.string,
  className: _propTypes.default.string
};

var _default = (
/*#__PURE__*/
0, _styledBase.default)(Icon, {
  target: "ei6fm2r1"
})();

exports.default = _default;