"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Loader = void 0;

var _styledBase = _interopRequireDefault(require("@emotion/styled-base"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _core = require("@emotion/core");

var _CSSTransition = _interopRequireDefault(require("react-transition-group/CSSTransition"));

var _styles = require("./styles");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const styles = {
  disabled: {
    name: "v06iuk-disabled",
    styles: "display:none;label:disabled;"
  },
  active: {
    name: "1426nog-active",
    styles: "display:block;label:active;"
  },
  enter: {
    name: "1rrod3j-enter",
    styles: "opacity:0.01;label:enter;"
  },
  enterActive: {
    name: "ssvs1t-enterActive",
    styles: "opacity:1;transition:opacity 500ms ease-in;label:enterActive;"
  },
  exit: {
    name: "t407yk-exit",
    styles: "opacity:1;label:exit;"
  },
  exitActive: {
    name: "1npgmu6-exitActive",
    styles: "opacity:0.01;transition:opacity 300ms ease-in;label:exitActive;"
  }
};
const animations = {
  loader: _core.keyframes`
    from {
      transform: rotate(0deg);
    }

    to {
      transform: rotate(360deg);
    }
  `
};
const LoaderText = (0, _styledBase.default)("div", {
  target: "e1rlflmg0",
  label: "LoaderText"
})({
  name: "8sb4j5",
  styles: "width:auto !important;height:auto !important;text-align:center;color:#767676;margin-top:55px;line-height:35px;"
});
const LoaderItem = (0, _styledBase.default)("div", {
  target: "e1rlflmg1",
  label: "LoaderItem"
})({
  name: "aprmr",
  styles: "position:absolute;white-space:nowrap;transform:translateX(-50%);"
});

class Loader extends _react.default.Component {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      currentItem: 0
    });

    _defineProperty(this, "setAnimation", () => {
      if (this.interval) return;
      const children = this.props.children;
      this.interval = setInterval(() => {
        const nextItem = this.state.currentItem === children.length - 1 ? 0 : this.state.currentItem + 1;
        this.setState({
          currentItem: nextItem
        });
      }, 5000);
    });

    _defineProperty(this, "renderChild", () => {
      const children = this.props.children;
      const currentItem = this.state.currentItem;

      if (!children) {
        return null;
      } else if (typeof children == 'string') {
        return _react.default.createElement(LoaderText, null, children);
      } else if (Array.isArray(children)) {
        this.setAnimation();
        return _react.default.createElement(LoaderText, null, _react.default.createElement(_CSSTransition.default, {
          classNames: {
            enter: styles.enter,
            enterActive: styles.enterActive,
            exit: styles.exit,
            exitActive: styles.exitActive
          },
          timeout: 500
        }, _react.default.createElement(LoaderItem, {
          key: currentItem
        }, children[currentItem])));
      }
    });
  }

  componentWillUnmount() {
    if (this.interval) {
      clearInterval(this.interval);
    }
  }

  render() {
    const className = this.props.className;
    return _react.default.createElement("div", {
      className: className
    }, this.renderChild());
  }

}

exports.Loader = Loader;

_defineProperty(Loader, "propTypes", {
  children: _propTypes.default.node,
  className: _propTypes.default.string
});

const StyledLoader = (
/*#__PURE__*/
0, _styledBase.default)(Loader, {
  target: "e1rlflmg2",
  label: "StyledLoader"
})("display:", props => props.active ? 'block' : 'none', ";position:absolute;top:50%;left:50%;margin:0px;text-align:center;z-index:1000;transform:translateX(-50%) translateY(-50%);&:before,&:after{content:'';position:absolute;top:0%;left:50%;width:2.28571429rem;height:2.28571429rem;margin:0em 0em 0em -1.14285714rem;border-radius:500rem;border-style:solid;border-width:0.2em;}&:before{border-color:rgba(0,0,0,0.1);}&:after{animation:", animations.loader, " 0.6s linear;animation-iteration-count:infinite;border-color:", _styles.colors.active, " transparent transparent;box-shadow:0px 0px 0px 1px transparent;}");
var _default = StyledLoader;
exports.default = _default;