"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GlobalStyles = exports.reactSelectStyles = exports.effects = exports.transitions = exports.borders = exports.shadows = exports.buttons = exports.components = exports.lengths = exports.colors = exports.colorsRaw = exports.fonts = void 0;

var _react = _interopRequireDefault(require("react"));

var _core = require("@emotion/core");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Font Stacks
 */
const fonts = {
  primary: `
    -apple-system,
    BlinkMacSystemFont,
    "Segoe UI",
    Roboto,
    Helvetica,
    Arial,
    sans-serif,
    "Apple Color Emoji",
    "Segoe UI Emoji",
    "Segoe UI Symbol"
  `,
  mono: `
    'SFMono-Regular',
    Consolas,
    "Liberation Mono",
    Menlo,
    Courier,
    monospace;
  `
};
/**
 * Theme Colors
 */

exports.fonts = fonts;
const colorsRaw = {
  white: '#fff',
  grayLight: '#eff0f4',
  gray: '#798291',
  grayDark: '#313d3e',
  blue: '#3a69c7',
  blueLight: '#e8f5fe',
  green: '#005614',
  greenLight: '#caef6f',
  brown: '#754e00',
  yellow: '#ffee9c',
  red: '#ff003b',
  redLight: '#fcefea',
  purple: '#70399f',
  purpleLight: '#f6d8ff',
  teal: '#17a2b8',
  tealLight: '#ddf5f9'
};
exports.colorsRaw = colorsRaw;
const colors = {
  statusDraftText: colorsRaw.purple,
  statusDraftBackground: colorsRaw.purpleLight,
  statusReviewText: colorsRaw.Brown,
  statusReviewBackground: colorsRaw.yellow,
  statusReadyText: colorsRaw.green,
  statusReadyBackground: colorsRaw.greenLight,
  text: colorsRaw.gray,
  textLight: colorsRaw.white,
  textLead: colorsRaw.grayDark,
  background: colorsRaw.grayLight,
  foreground: colorsRaw.white,
  active: colorsRaw.blue,
  activeBackground: colorsRaw.blueLight,
  inactive: colorsRaw.gray,
  button: colorsRaw.gray,
  buttonText: colorsRaw.white,
  inputBackground: colorsRaw.white,
  infoText: colorsRaw.blue,
  infoBackground: colorsRaw.blueLight,
  successText: colorsRaw.green,
  successBackground: colorsRaw.greenLight,
  warnText: colorsRaw.brown,
  warnBackground: colorsRaw.yellow,
  errorText: colorsRaw.red,
  errorBackground: colorsRaw.redLight,
  textFieldBorder: '#dfdfe3',
  controlLabel: '#7a8291',
  checkerboardLight: '#f2f2f2',
  checkerboardDark: '#e6e6e6'
};
exports.colors = colors;
const lengths = {
  topBarHeight: '56px',
  inputPadding: '16px 20px',
  borderRadius: '5px',
  richTextEditorMinHeight: '300px',
  borderWidth: '2px',
  topCardWidth: '682px',
  pageMargin: '28px 18px',
  objectWidgetTopBarContainerPadding: '0 14px 14px'
};
exports.lengths = lengths;
const borders = {
  textField: `solid  ${lengths.borderWidth} ${colors.textFieldBorder}`
};
exports.borders = borders;
const transitions = {
  main: '.2s ease'
};
exports.transitions = transitions;
const shadows = {
  drop: {
    name: "1048azx-drop",
    styles: "box-shadow:0 2px 4px 0 rgba(19,39,48,0.12);label:drop;"
  },
  dropMain: {
    name: "5wb486-dropMain",
    styles: "box-shadow:0 2px 6px 0 rgba(68,74,87,0.05),0 1px 3px 0 rgba(68,74,87,0.1);label:dropMain;"
  },
  dropMiddle: {
    name: "968vwo-dropMiddle",
    styles: "box-shadow:0 2px 6px 0 rgba(68,74,87,0.15),0 1px 3px 0 rgba(68,74,87,0.3);label:dropMiddle;"
  },
  dropDeep: {
    name: "1sg7m5i-dropDeep",
    styles: "box-shadow:0 4px 12px 0 rgba(68,74,87,0.15),0 1px 3px 0 rgba(68,74,87,0.25);label:dropDeep;"
  },
  inset: {
    name: "1qqzxv-inset",
    styles: "box-shadow:inset 0 0 4px rgba(68,74,87,0.3);label:inset;"
  }
};
exports.shadows = shadows;
const gradients = {
  checkerboard: `
    linear-gradient(
      45deg,
      ${colors.checkerboardDark} 25%,
      transparent 25%,
      transparent 75%,
      ${colors.checkerboardDark} 75%,
      ${colors.checkerboardDark}
    )
  `
};
const effects = {
  checkerboard:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colors.checkerboardLight, ";background-size:16px 16px;background-position:0 0,8px 8px;background-image:", gradients.checkerboard, ",", gradients.checkerboard, ";label:checkerboard;")
};
exports.effects = effects;
const badge = {
  name: "1bvw0ad-badge",
  styles: "font-size:13px;line-height:1;label:badge;"
};
const backgroundBadge =
/*#__PURE__*/
(0, _core.css)(badge, ";display:block;border-radius:", lengths.borderRadius, ";padding:4px 10px;text-align:center;label:backgroundBadge;");
const textBadge =
/*#__PURE__*/
(0, _core.css)(badge, ";display:inline-block;font-weight:700;text-transform:uppercase;label:textBadge;");
const card =
/*#__PURE__*/
(0, _core.css)(shadows.dropMain, ";border-radius:5px;background-color:#fff;label:card;");
const buttons = {
  button:
  /*#__PURE__*/
  (0, _core.css)("border:0;border-radius:", lengths.borderRadius, ";cursor:pointer;label:button;"),
  default:
  /*#__PURE__*/
  (0, _core.css)("height:36px;line-height:36px;font-weight:500;padding:0 15px;background-color:", colorsRaw.gray, ";color:", colorsRaw.white, ";label:default;"),
  medium: {
    name: "xdagg1-medium",
    styles: "height:27px;line-height:27px;font-size:12px;font-weight:600;border-radius:3px;padding:0 24px 0 14px;label:medium;"
  },
  small: {
    name: "tf40rb-small",
    styles: "height:23px;line-height:23px;label:small;"
  },
  gray:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colors.button, ";color:", colors.buttonText, ";&:focus,&:hover{color:", colors.white, ";background-color:#555a65;}label:gray;"),
  green:
  /*#__PURE__*/
  (0, _core.css)("background-color:#aae31f;color:", colorsRaw.green, ";label:green;"),
  lightRed:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colorsRaw.redLight, ";color:", colorsRaw.red, ";label:lightRed;"),
  lightBlue:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colorsRaw.blueLight, ";color:", colorsRaw.blue, ";label:lightBlue;"),
  lightTeal:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colorsRaw.tealLight, ";color:#1195aa;label:lightTeal;"),
  teal:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colorsRaw.teal, ";color:", colorsRaw.white, ";label:teal;"),
  disabled:
  /*#__PURE__*/
  (0, _core.css)("background-color:", colorsRaw.grayLight, ";color:", colorsRaw.gray, ";label:disabled;")
};
exports.buttons = buttons;
const components = {
  card,
  caretDown:
  /*#__PURE__*/
  (0, _core.css)("color:", colorsRaw.white, ";width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid currentColor;border-radius:2px;label:caretDown;"),
  badge:
  /*#__PURE__*/
  (0, _core.css)(backgroundBadge, ";color:", colors.infoText, ";background-color:", colors.infoBackground, ";label:badge;"),
  badgeSuccess:
  /*#__PURE__*/
  (0, _core.css)(backgroundBadge, ";color:", colors.successText, ";background-color:", colors.successBackground, ";label:badgeSuccess;"),
  badgeDanger:
  /*#__PURE__*/
  (0, _core.css)(backgroundBadge, ";color:", colorsRaw.red, ";background-color:#fbe0d7;label:badgeDanger;"),
  textBadge:
  /*#__PURE__*/
  (0, _core.css)(textBadge, ";color:", colors.infoText, ";label:textBadge;"),
  textBadgeSuccess:
  /*#__PURE__*/
  (0, _core.css)(textBadge, ";color:", colors.successText, ";label:textBadgeSuccess;"),
  textBadgeDanger:
  /*#__PURE__*/
  (0, _core.css)(textBadge, ";color:", colorsRaw.red, ";label:textBadgeDanger;"),
  loaderSize: {
    name: "e7t4gf-loaderSize",
    styles: "width:2.28571429rem;height:2.28571429rem;label:loaderSize;"
  },
  cardTop:
  /*#__PURE__*/
  (0, _core.css)(card, ";width:", lengths.topCardWidth, ";max-width:100%;padding:18px 20px;margin-bottom:28px;label:cardTop;"),
  cardTopHeading: {
    name: "1jf7yv6-cardTopHeading",
    styles: "font-size:22px;font-weight:600;line-height:37px;margin:0;padding:0;label:cardTopHeading;"
  },
  cardTopDescription:
  /*#__PURE__*/
  (0, _core.css)("max-width:480px;color:", colors.text, ";font-size:14px;margin-top:8px;label:cardTopDescription;"),
  objectWidgetTopBarContainer:
  /*#__PURE__*/
  (0, _core.css)("padding:", lengths.objectWidgetTopBarContainerPadding, ";label:objectWidgetTopBarContainer;"),
  dropdownList:
  /*#__PURE__*/
  (0, _core.css)(shadows.dropDeep, ";background-color:", colorsRaw.white, ";border-radius:", lengths.borderRadius, ";overflow:hidden;label:dropdownList;"),
  dropdownItem:
  /*#__PURE__*/
  (0, _core.css)(buttons.button, ";background-color:transparent;border-radius:0;color:", colorsRaw.gray, ";font-weight:500;border-bottom:1px solid #eaebf1;padding:10px 14px;display:flex;justify-content:space-between;align-items:center;&:last-of-type{border-bottom:0;}&:hover,&:active,&:focus{color:", colors.active, ";background-color:", colors.activeBackground, ";}label:dropdownItem;")
};
exports.components = components;
const reactSelectStyles = {
  control: styles => _objectSpread({}, styles, {
    border: 0,
    boxShadow: 'none',
    padding: '9px 0 9px 12px'
  }),
  option: (styles, state) => _objectSpread({}, styles, {
    backgroundColor: state.isSelected ? `${colors.active}` : state.isFocused ? `${colors.activeBackground}` : 'transparent',
    paddingLeft: '22px'
  }),
  menu: styles => _objectSpread({}, styles, {
    right: 0,
    zIndex: 2
  }),
  container: styles => _objectSpread({}, styles, {
    padding: '0 !important'
  }),
  indicatorSeparator: (styles, state) => state.hasValue && state.selectProps.isClearable ? _objectSpread({}, styles, {
    backgroundColor: `${colors.textFieldBorder}`
  }) : {
    display: 'none'
  },
  dropdownIndicator: styles => _objectSpread({}, styles, {
    color: `${colors.controlLabel}`
  }),
  clearIndicator: styles => _objectSpread({}, styles, {
    color: `${colors.controlLabel}`
  }),
  multiValue: styles => _objectSpread({}, styles, {
    backgroundColor: colors.background
  }),
  multiValueLabel: styles => _objectSpread({}, styles, {
    color: colors.textLead,
    fontWeight: 500
  }),
  multiValueRemove: styles => _objectSpread({}, styles, {
    color: colors.controlLabel,
    ':hover': {
      color: colors.errorText,
      backgroundColor: colors.errorBackground
    }
  })
};
exports.reactSelectStyles = reactSelectStyles;

const GlobalStyles = () => _react.default.createElement(_core.Global, {
  styles:
  /*#__PURE__*/
  (0, _core.css)("*,*:before,*:after{box-sizing:border-box;}:focus{outline:-webkit-focus-ring-color auto ", lengths.borderRadius, ";}[data-whatintent='mouse'] *:focus{outline:none;}input{border:0;}body{font-family:", fonts.primary, ";font-weight:normal;background-color:", colors.background, ";color:", colors.text, ";margin:0;}ul,ol{padding-left:0;}h1,h2,h3,h4,h5,h6,p{font-family:", fonts.primary, ";color:", colors.textLead, ";font-size:15px;line-height:1.5;margin-top:0;}h1,h2,h3,h4,h5,h6{font-weight:500;}h1{font-size:24px;letter-spacing:0.4px;color:", colors.textLead, ";}a,button{font-size:14px;font-weight:500;}a{color:", colors.text, ";text-decoration:none;}img{max-width:100%;}textarea{resize:none;}label:GlobalStyles;")
});

exports.GlobalStyles = GlobalStyles;